==> org.apache.sling.event-3.3.14-sources.jar: org/apache/sling/event/impl/jobs/jmx/QueueMBeanImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The SF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.apache.sling.event.impl.jobs.jmx;

import org.apache.sling.event.jobs.Queue;
import org.apache.sling.event.jobs.Statistics;

/**
 * An MBean that provides statistics from
 */
public class QueueMBeanImpl extends AbstractJobStatistics {

    private final String name;

    private final Statistics statistics;

    public QueueMBeanImpl(Queue queue) {
        this.name = queue.getName();
        if (queue instanceof Statistics) {
            this.statistics = (Statistics) queue;
        } else {
            this.statistics = new EmptyStatistics();
        }
    }

    @Override
    protected Statistics getStatistics() {
        return this.statistics;
    }

    @Override
    public String getName() {
        return name;
    }
}

==> org.apache.sling.event-4.3.18-sources.jar: org/apache/sling/event/impl/jobs/jmx/QueueMBeanImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The SF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.apache.sling.event.impl.jobs.jmx;

import org.apache.sling.event.jobs.Queue;
import org.apache.sling.event.jobs.Statistics;

/**
 * An MBean that provides statistics from
 */
public class QueueMBeanImpl extends AbstractJobStatistics {

    private final String name;

    private final Statistics statistics;

    public QueueMBeanImpl(Queue queue) {
        this.name = queue.getName();
        Statistics stats = queue instanceof Statistics ? (Statistics) queue : queue.getStatistics();
        this.statistics = stats != null ? stats : new EmptyStatistics();
    }

    @Override
    protected Statistics getStatistics() {
        return this.statistics;
    }

    @Override
    public String getName() {
        return name;
    }
}
